Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RemoteJob ¶
type RemoteJob struct {
net.Conn
Server Server
SSHConf *ssh.ClientConfig
Timeout time.Duration
Responses chan string
Errors chan error
WaitGroup *sync.WaitGroup
SpecList *specr.SpecList
SpecName string
Client *ssh.Client
}
Remote Job
type Server ¶
type Server struct {
Name string `ini:"-"` // considered Sections in config file
Host string
Username string
Spec string
PassAuth bool
Password string `ini:"-"` // Not stored in config, just where it gets temporarily stored when we ask for it.
}
Represents a single remote server
func (*Server) PrintServerInfo ¶
func (s *Server) PrintServerInfo()
Prints a single server config data in a table
Click to show internal directories.
Click to hide internal directories.